//
//  ArchitectureLoading.swift
//  iOS Architectures
//
//  Created by Dave DeLong on 10/28/17.
//  Copyright © 2017 Dave DeLong. All rights reserved.
//

import Foundation

// A simple Result enum. A proper enum would have a more strongly-typed failure case,
// but we don't need that for this simple case
enum Result<T> {
    case success(T)
    case failure(String)
}

// A model describing a random iOS architecture
// It's created from JSON, so we can take advantage of conforming to Decodable
struct Architecture: Decodable {
    
    enum CodingKeys: String, CodingKey {
        case acronym = "initialism"
        case description = "name"
    }
    
    let acronym: String
    let description: String
}

// By specifying the loading of an architecture via a protocol, it is easier to unit test how it's used
protocol ArchitectureLoading {
    
    func loadArchitecture(_ completion: @escaping (Result<Architecture>) -> Void)
    
}
