//
//  ArchitectureViewController.swift
//  iOS Architectures
//
//  Created by Dave DeLong on 10/27/17.
//  Copyright © 2017 Dave DeLong. All rights reserved.
//

import UIKit

protocol ArchitectureViewControllerDelegate: class {
    func architectureViewControllerActionButtonWasTapped(_ sender: ArchitectureViewController)
}

/// A view controller that displays the acronym and name of an architecture
class ArchitectureViewController: UIViewController {
    
    weak var delegate: ArchitectureViewControllerDelegate?
    
    private let architecture: Architecture
    
    @IBOutlet var acronymLabel: UILabel?
    @IBOutlet var descriptionLabel: UILabel?
    
    init(architecture: Architecture) {
        self.architecture = architecture
        super.init(nibName: nil, bundle: nil)
    }
    
    required init?(coder aDecoder: NSCoder) { fatalError("die") }
    
    override func viewDidLoad() {
        super.viewDidLoad()

        acronymLabel?.text = architecture.acronym
        descriptionLabel?.text = architecture.description
    }
    
    @IBAction func generateAnother(_ sender: UIButton) {
        delegate?.architectureViewControllerActionButtonWasTapped(self)
    }

}
